#!/bin/sh
# Checks some OS requirements needed by SEPsesam server
# Should be executed before sm_setup is started
VERSION='$Id: sm_check_preinst.sh,v 1.5 2005/09/20 08:36:02 sesam Exp $'
hostname=`uname -n`
os=`uname -s|tr  '[:lower:]' '[:upper:]'`
LOG="/tmp/sm_setup.log 2>&1"
sesamserver=$hostname

[ -z "$gv_rw" ]       && gv_rw="$gv_ro"
[ -z "$servername" ]  && name=`uname -n`
[ -z "$os" ]          && os=`uname -s|tr  '[:lower:]' '[:upper:]'`


check_java()
{
  ECHO "Check 'java' installation"
  java_cmd=${java_cmd:-java} 
  type ${java_cmd} || err "'java' not found" 
  JAVA_VERSION=`${java_cmd} -version 2>&1`
  JAVA_VERSION=`expr "$JAVA_VERSION" : '.*\(1\.[0-9\.]*\)'`
  ECHO "Found java version: '${JAVA_VERSION}'."
  echo ${JAVA_VERSION}|grep "^1\.[45]." >/dev/null \
                || err "Sesam needs java version >= 1.4" 
  ECHO "->OK"
  ECHO "-------------------------------------------"
}


check_sesamuser()
{
  ECHO "Check for user 'sesam'"
  id sesam  || err "user 'sesam' not found. Please add user 'sesam'"
  id -ng sesam|grep sesam || err "user 'sesam' not in group 'sesam'"
  ECHO "->OK"
  ECHO "-------------------------------------------"
}

check_rootuser()
{
  ECHO "Check if we are root"
  [ `id -u` != 0 ] && err "You have to be 'root' for installing SEPsesam"
  ECHO "->OK"
  ECHO "-------------------------------------------"
}

check_path()
{
  ECHO "Check for correct PATH on Solaris"
  [ `which id` = "/usr/bin/id" ] && err "Please add '/usr/xpg4/bin' at the beginning of your 'PATH' variable"
  ECHO "->OK"
  ECHO "-------------------------------------------"
}


check_db()
{
  PG_PRG="postmaster initdb psql createuser createdb"
  ECHO "Check 'postgresql' installation"
  for PRG in $PG_PRG; do
  ECHO "Check '$PRG' ..."
  su - sesam -c "type $PRG" || err "$PRG not in PATH of user 'sesam'" 
  done
  ECHO "->OK"
  ECHO "-------------------------------------------"
  ECHO "Check if we can start 'postgresql' executables ..."
  su - sesam -c 'ldd `which createdb`' || err "Can not find 'createdb'"
  not_found=`su - sesam -c 'ldd \`which createdb\`' 2>&1|grep -v libsm.so| grep "not found"` && err "Could not load shared library '$not_found'\nPlease check your 'LD_LIBRARY_PATH'" 
  ECHO "->OK"
  ECHO "-------------------------------------------"
  ECHO "Check if we can load shared libraries ..."
  ldd sm_test 2>&1 || err "Can not find 'sm_test'"
  not_found=`ldd sm_test 2>&1|grep -v libsm.so| grep "not found"` && err "Could not load shared library '$not_found'\nPlease check your 'LD_LIBRARY_PATH'" 
  ECHO "->OK"
  ECHO "-------------------------------------------"
}


err()
{
  ECHO "$1"
  exit 1
}
ECHO()
{
  echo "$*"
}

ECHO "$VERSION"
ECHO "-------------------------------------------"
ECHO "Check Sesam installation requirements"
ECHO "-------------------------------------------"
ECHO "Hostname               : "$hostname
ECHO "Operating system       : $os"
ECHO "-------------------------------------------"
[ `uname` = "SunOS" ] && check_path
check_rootuser
check_java
check_sesamuser
check_db
ECHO "-------------------------------------------"
ECHO "Check successfully done"
ECHO "You can start installation by executing './sm_setup' now."
exit 0

